<?php

require_once('UIApplication.php');
require_once('Models/Setting.php');
require_once('Models/User.php');


class Application extends UIApplication
{
	
	public $deubgEnabled = true;
	public $debugCount = 0;
	
	public $dbType;
	public $dbFileName;
	public $dbLocation;
	public $dbUsername;
	public $dbPassword;


	public $requestMethod;
	public $scriptPath;
	
	
	public $view;
	public $user;
	
	
	function init()
	{	
	
		// 設定時間時區
		date_default_timezone_set('Asia/Taipei');
		
		
		// 啟動除錯功能
		if($this->deubgEnabled == true)
		{
			require_once('Library/PhpConsole/PhpConsole.php');
			PhpConsole::start(true, true, dirname(__FILE__));
		}
		
		
		// 設定環境變數
		//$this->debug("Application init");
		//$this->debug('REQUEST_METHOD為'.$_SERVER['REQUEST_METHOD']);
		//$this->debug('REQUEST_URI為'.$_SERVER['REQUEST_URI']);
		//$this->debug('SCRIPT_NAME為'.$_SERVER['SCRIPT_NAME']);
		$this->requestMethod = $_SERVER['REQUEST_METHOD'];
		$this->scriptPath = dirname($_SERVER['SCRIPT_NAME']).'/';
		
		
		// 設定資料庫
		$type = 'sqlite';
		//$type = 'mysql';
		if($type == 'mysql')
		{
			$this->dbType = 'mysql';
			$this->dbLocation = 'host=localhost;dbname=startup';
			$this->dbUsername = 'root';
			$this->dbPassword = '';
		}
		else
		{
			$this->dbType = 'sqlite';
			$this->dbFileName = 'AppData/Database/startup.sqlite';
		}
		
		
		
		
		// 設定view基本資料
		$this->view = (object)array();
		$this->view->title = 'startup';
		$this->view->path = $this->scriptPath;
		$this->view->menu = '';
		$this->view->isLogin = false;
		$this->view->nickname = '';

		$this->user = null;
		
		
	
		// 讀取session
		if(isset($_SESSION['isLogin']) == true)
		{
			if($_SESSION['isLogin'] == true)
			{
				$userID = $_SESSION['userID'];
				$this->user = User::find($userID); 
				
				$this->view->isLogin = $_SESSION['isLogin'];
				$this->view->nickname = $this->user->username;
			}
		}

		
		
		
		// 讀取資料庫版本
		$settings = Setting::findByConditions("WHERE name=?", array('version'));
		for($i=0;$i<count($settings);$i++)
		{
			$setting = $settings[$i];
			$this->debug($setting->name.' => '.$setting->value);
			
			$wantedDatabaseVersion = 1;
			if($setting->value != $wantedDatabaseVersion)
			{
				echo '<html><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>快樂教學王 - Social Teaching</title></head><span style="font-size:200%;color:#666">';
				echo '# 我們正在升級資料庫<br/># 請稍候';
				echo '</span></html>';
				exit();
			}
		}
		
		
		// 除錯訊息，顯示session的有效時間
		//$this->debug("session : ".ini_get("session.gc_maxlifetime"));

	}
	

	function launch()
	{	
		$time1 = microtime();
		
		$this->debug('開始除錯');
		$this->debug("Application launch");
		$this->route();
		$this->debug('結束除錯');
		
		$time2 = microtime();
		$this->debug($time2-$time1);
	}
	
	
	function route()
	{
		$this->debug("Application route");
		
		$routeMapping = array(
			'' => 'AppViewController',
 			'event' => 'DSEventViewController',
 			'message' => 'DSMessageViewController'
		);
		//$this->debug(print_r($mapping, true));
		

		$route = '';
		if($_GET['route'] != '')
		{
			$route = $_GET['route'];
		}
		else
		{
			$route = '';
		}
		//$this->debug('route='.$route);
		
		
		
		$routeArray = explode('/', $route);
		$currentRoute = array_shift($routeArray);
		
		$controllerName = '';
		if(array_key_exists($currentRoute, $routeMapping) == true)
		{
			$controllerName = $routeMapping[$currentRoute];
		}
		else
		{
			array_unshift($routeArray, $currentRoute);
			$controllerName = $routeMapping[''];
		}
		
		
		
		
		require_once($controllerName.'.php');
		$controller = new $controllerName;
		$controller->init();
		$controller->show($routeArray);
		
		
		
		//$controller = new AppViewController;
		//$controller->init();
		//$controller->showView($message);
		
	}
	
	
	function debug($message)
	{
		if($this->deubgEnabled == false)
		{
			return;
		}
		
		$this->debugCount++;
		debug($message);
	}

}


?>